@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -11,15 +14,16 @@ import typing_extensions
 from typeguard import check_type
 
 import aws_cdk._jsii
+import aws_cdk.integ_tests_alpha._jsii
 import aws_solutions_constructs.aws_cloudfront_apigateway._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-cloudfront-apigateway-lambda",
-    "2.50.0",
+    "2.56.0",
     __name__[0:-6],
-    "aws-cloudfront-apigateway-lambda@2.50.0.jsii.tgz",
+    "aws-cloudfront-apigateway-lambda@2.56.0.jsii.tgz",
 )
 
 __all__ = [
